---
title: <span class="badge object-type-scalar"></span> ArcSeconds
---
# <span class="badge object-type-scalar"></span> ArcSeconds

Angle: Arc Seconds

## Definition

```python
# Angle: Arc Seconds
ArcSeconds: typing.Literal["arcsec"] = "arcsec"
```
